@@ -2,20 +2,13 @@
 
 import ast
 import re
+from collections.abc import Iterable, Iterator
 from string import Formatter
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    NamedTuple,
-    Optional,
-    Tuple,
-)
+from typing import Any, Callable, NamedTuple, Optional
 
+from sqlfluff.core.config import FluffConfig
 from sqlfluff.core.errors import SQLTemplaterError
+from sqlfluff.core.formatter import FormatterInterface
 from sqlfluff.core.helpers.slice import offset_slice, zero_slice
 from sqlfluff.core.helpers.string import findall
 from sqlfluff.core.templaters.base import (
@@ -34,11 +27,11 @@ class IntermediateFileSlice(NamedTuple):
     intermediate_type: str
     source_slice: slice
     templated_slice: slice
-    slice_buffer: List[RawFileSlice]
+    slice_buffer: list[RawFileSlice]
 
     def _trim_end(
         self, templated_str: str, target_end: str = "head"
-    ) -> Tuple["IntermediateFileSlice", List[TemplatedFileSlice]]:
+    ) -> tuple["IntermediateFileSlice", list[TemplatedFileSlice]]:
         """Trim the ends of a intermediate segment."""
         target_idx = 0 if target_end == "head" else -1
         terminator_types = ("block_start") if target_end == "head" else ("block_end")
@@ -120,8 +113,8 @@ class IntermediateFileSlice(NamedTuple):
 
     def trim_ends(
         self, templated_str: str
-    ) -> Tuple[
-        List[TemplatedFileSlice], "IntermediateFileSlice", List[TemplatedFileSlice]
+    ) -> tuple[
+        list[TemplatedFileSlice], "IntermediateFileSlice", list[TemplatedFileSlice]
     ]:
         """Trim both ends of an intermediate slice."""
         # Trim start:
@@ -169,13 +162,14 @@ class PythonTemplater(RawTemplater):
     """
 
     name = "python"
+    config_subsection: tuple[str, ...] = ("context",)
 
-    def __init__(self, override_context=None, **kwargs) -> None:
+    def __init__(self, override_context: Optional[dict[str, Any]] = None) -> None:
         self.default_context = dict(test_value="__test__")
         self.override_context = override_context or {}
 
     @staticmethod
-    def infer_type(s) -> Any:
+    def infer_type(s: Any) -> Any:
         """Infer a python type from a string and convert.
 
         Given a string value, convert it to a more specific built-in Python type
@@ -187,7 +181,11 @@ class PythonTemplater(RawTemplater):
         except (SyntaxError, ValueError):
             return s
 
-    def get_context(self, fname=None, config=None, **kw) -> Dict:
+    def get_context(
+        self,
+        fname: Optional[str],
+        config: Optional[FluffConfig],
+    ) -> dict[str, Any]:
         """Get the templating context from the config.
 
         This function retrieves the templating context from the config by
@@ -199,35 +197,25 @@ class PythonTemplater(RawTemplater):
         Args:
             fname (str, optional): The file name.
             config (dict, optional): The config dictionary.
-            **kw: Additional keyword arguments.
 
         Returns:
             dict: The templating context.
         """
-        # TODO: The config loading should be done outside the templater code. Here
-        # is a silly place.
-        if config:
-            # This is now a nested section
-            loaded_context = (
-                config.get_section((self.templater_selector, self.name, "context"))
-                or {}
-            )
-        else:
-            loaded_context = {}
-        live_context = {}
-        live_context.update(self.default_context)
-        live_context.update(loaded_context)
-        live_context.update(self.override_context)
-
+        live_context = super().get_context(fname, config)
         # Infer types
-        for k in loaded_context:
+        for k in live_context:
             live_context[k] = self.infer_type(live_context[k])
         return live_context
 
     @large_file_check
     def process(
-        self, *, in_str: str, fname: str, config=None, formatter=None
-    ) -> Tuple[TemplatedFile, List[SQLTemplaterError]]:
+        self,
+        *,
+        in_str: str,
+        fname: str,
+        config: Optional[FluffConfig] = None,
+        formatter: Optional[FormatterInterface] = None,
+    ) -> tuple[TemplatedFile, list[SQLTemplaterError]]:
         """Process a string and return a TemplatedFile.
 
         Note that the arguments are enforced as keywords
@@ -247,7 +235,7 @@ class PythonTemplater(RawTemplater):
             formatter (:obj:`CallbackFormatter`): Optional object for output.
 
         """
-        live_context = self.get_context(fname=fname, config=config)
+        live_context = self.get_context(fname, config)
 
         def render_func(raw_str: str) -> str:
             """Render the string using the captured live_context.
@@ -314,8 +302,12 @@ class PythonTemplater(RawTemplater):
         )
 
     def slice_file(
-        self, raw_str: str, render_func: Callable[[str], str], config=None, **kwargs
-    ) -> Tuple[List[RawFileSlice], List[TemplatedFileSlice], str]:
+        self,
+        raw_str: str,
+        render_func: Callable[[str], str],
+        config: Optional[FluffConfig] = None,
+        append_to_templated: str = "",
+    ) -> tuple[list[RawFileSlice], list[TemplatedFileSlice], str]:
         """Slice the file to determine regions where we can fix."""
         templater_logger.info("Slicing File Template")
         templater_logger.debug("    Raw String: %r", raw_str)
@@ -390,10 +382,10 @@ class PythonTemplater(RawTemplater):
     @classmethod
     def _check_for_wrapped(
         cls,
-        slices: List[TemplatedFileSlice],
+        slices: list[TemplatedFileSlice],
         templated_str: str,
         unwrap_wrapped: bool = True,
-    ) -> Tuple[List[TemplatedFileSlice], str]:
+    ) -> tuple[list[TemplatedFileSlice], str]:
         """Identify a wrapped query (e.g. dbt test) and handle it.
 
         If unwrap_wrapped is true, we trim the wrapping from the templated
@@ -451,7 +443,7 @@ class PythonTemplater(RawTemplater):
     @classmethod
     def _substring_occurrences(
         cls, in_str: str, substrings: Iterable[str]
-    ) -> Dict[str, List[int]]:
+    ) -> dict[str, list[int]]:
         """Find every occurrence of the given substrings."""
         occurrences = {}
         for substring in substrings:
@@ -460,8 +452,8 @@ class PythonTemplater(RawTemplater):
 
     @staticmethod
     def _sorted_occurrence_tuples(
-        occurrences: Dict[str, List[int]]
-    ) -> List[Tuple[str, int]]:
+        occurrences: dict[str, list[int]],
+    ) -> list[tuple[str, int]]:
         """Sort a dict of occurrences into a sorted list of tuples."""
         return sorted(
             ((raw, idx) for raw in occurrences.keys() for idx in occurrences[raw]),
@@ -519,10 +511,10 @@ class PythonTemplater(RawTemplater):
     @classmethod
     def _split_invariants(
         cls,
-        raw_sliced: List[RawFileSlice],
-        literals: List[str],
-        raw_occurrences: Dict[str, List[int]],
-        templated_occurrences: Dict[str, List[int]],
+        raw_sliced: list[RawFileSlice],
+        literals: list[str],
+        raw_occurrences: dict[str, list[int]],
+        templated_occurrences: dict[str, list[int]],
         templated_str: str,
     ) -> Iterator[IntermediateFileSlice]:
         """Split a sliced file on its invariant literals.
@@ -563,7 +555,7 @@ class PythonTemplater(RawTemplater):
                         invariants.remove(tinv)
 
         # Set up some buffers
-        buffer: List[RawFileSlice] = []
+        buffer: list[RawFileSlice] = []
         idx: Optional[int] = None
         templ_idx = 0
         # Loop through
@@ -620,8 +612,8 @@ class PythonTemplater(RawTemplater):
 
     @staticmethod
     def _filter_occurrences(
-        file_slice: slice, occurrences: Dict[str, List[int]]
-    ) -> Dict[str, List[int]]:
+        file_slice: slice, occurrences: dict[str, list[int]]
+    ) -> dict[str, list[int]]:
         """Filter a dict of occurrences to just those within a slice."""
         filtered = {
             key: [
@@ -634,7 +626,7 @@ class PythonTemplater(RawTemplater):
         return {key: filtered[key] for key in filtered.keys() if filtered[key]}
 
     @staticmethod
-    def _coalesce_types(elems: List[RawFileSlice]) -> str:
+    def _coalesce_types(elems: list[RawFileSlice]) -> str:
         """Coalesce to the priority type."""
         # Make a set of types
         types = {elem.slice_type for elem in elems}
@@ -658,9 +650,9 @@ class PythonTemplater(RawTemplater):
     @classmethod
     def _split_uniques_coalesce_rest(
         cls,
-        split_file: List[IntermediateFileSlice],
-        raw_occurrences: Dict[str, List[int]],
-        templ_occurrences: Dict[str, List[int]],
+        split_file: list[IntermediateFileSlice],
+        raw_occurrences: dict[str, list[int]],
+        templ_occurrences: dict[str, list[int]],
         templated_str: str,
     ) -> Iterator[TemplatedFileSlice]:
         """Within each of the compound sections split on unique literals.
@@ -673,7 +665,7 @@ class PythonTemplater(RawTemplater):
 
         """
         # A buffer to capture tail segments
-        tail_buffer: List[TemplatedFileSlice] = []
+        tail_buffer: list[TemplatedFileSlice] = []
 
         templater_logger.debug("    _split_uniques_coalesce_rest: %s", split_file)
 
@@ -969,7 +961,7 @@ class PythonTemplater(RawTemplater):
 
                     # Can we identify a meaningful portion of the patch
                     # to recurse a split?
-                    sub_section: Optional[List[RawFileSlice]] = None
+                    sub_section: Optional[list[RawFileSlice]] = None
                     # If it's the start, the slicing is easy
                     if (
                         starts[1] == int_file_slice.templated_slice.stop
